# CW2016-ReplicationCodes

[![License](https://img.shields.io/badge/license-BSD%203--clause-green.svg)](https://github.com/vcurdia/CW2016-ReplicationCodes/blob/master/LICENSE)

These codes reproduce the results in:

**Cúrdia, V., and M. Woodford (2016)**  
[The Central-Bank Balance Sheet as an Instrument of Monetary Policy](http://www.sciencedirect.com/science/article/pii/S0304393216301052)  
*Journal of Monetary Economics*, 84, pp. 30-65.

[Technical Appendix](https://github.com/vcurdia/CW2016-ReplicationCodes/blob/master/CW2016_Appendix.pdf)

These replication codes are available online at:  
https://github.com/vcurdia/CW2016-ReplicationCodes


# Requirements

## Matlab (R)
The codes were tested using Matlab (R) R2016b with the following toolboxes
- Symbolic Toolbox
- Optimization Toolbox

## LaTeX
LaTeX is used by some tools to compile certain documents.

`epstopdf`, included in most LaTeX releases, is used by some tools.


## Additional codes

Codes by [Vasco Cúrdia](http://www.frbsf.org/economic-research/economists/vasco-curdia/):
- [VC-Tools](https://github.com/vcurdia/VC-Tools), version 
  [v3.0.3](https://github.com/vcurdia/VC-Tools/releases/tag/v3.0.3)
- [ACR-LQ](https://github.com/vcurdia/ACR-LQ)
  joint with Filippo Altissimo and Diego Rodriguez Palenzuela, version 
  [v1.0.0](https://github.com/vcurdia/ACR-LQ/releases/tag/v1.0.0)

Codes by [Chris Sims](http://www.princeton.edu/~sims/):
- [gensys](http://sims.princeton.edu/yftp/gensys/)
- [optimize](http://dge.repec.org/codes/sims/optimize/)

All auxiliary codes included in this repository in subfolders.


# Description of Replication Codes

`plotmgutil.m`
Generates Figure 1 of the paper showing the shape of the marginal utility for
the two types of households.


`RunAllModels.m`
Script that runs all models for a given parameterization. It generates
simulations for all shocks under optimal policy and alternative policy rules as
described in the paper and appendix.

Simulations are generated for three models:
- `FF`: model with financial frictions
  Simulations are generated by the function `IntModelFF.m`
- `NoFF`: model with heterogeneous households but no financial frictions
  Simulations are generated by the function `IntModelNoFF.m`
- `RepHH`: model with representative households.
  Simulations are generated by the function `IntModelRepHH.m`

Parameterization Flags:
- `End`
  Set to 0 to simulate linear financial intermediation technology, as in
  Figure 2 of the paper and Figures H1 through H9 of the appendix. Figure names
  are appended with '_Exo'. 
  Set to 1 to simulate convex financial intermediation technology, as in the
  remainder of the Figures. Figure names are appended with '_End'.
- `SmSigma`
  Set to 0 in baseline calibration, implying that the ratio of sigma_b to
  sigma_s is 5. 
  Set to 1 in order to generate the 'low-sigma_b' calibration, which sets
  sigma_b equal to sigma_s. Figures are appended with '_SmSigma'.
  
For each model the codes simulate responses to shocks under different policy
rules. The figure names are appended according to which rule is being used
according to the following:
- `LQ`: Optimal Policy
- `Pi`: Strict inflation stabilization (PiStab)
- `T`: Taylor rule as described in the paper
- `FT`: Flexible targeting criterion as described in the paper (FlexTarget)
- `TYn`: Taylor rule with output gap (instead of output deviations from trend)
  (TaylorYn) The results under this rule are shown in the appendix.


`PlotAll.m` Script that generates all the figures in pdf format. Figures for
each parameter configuration are stored in a subfolder with the appropriate
name.  It requires that `RunAllModels` was run before hand with the same
parameter flags.


`MakePlotsPDF.m`
Script that uses the figures generated with PlotAll and creates a tex report
with the following sections:
- One section for each policy comparing all three models.  
  These are useful to compare how adding household heterogeneity and financial
  frictions affect responses to the shocks.
- One section comparing all policy rules for the `FF` model.  
  These are useful to compare outcomes under alternative policies.
Each section has a subsection for each shock considered. 

